PowerImageInfo class

Inheritance
Implementers

Constructors

PowerImageInfo({required Image image, double scale = 1.0, String? debugLabel})

Properties

debugLabel → String?
A string used for debugging purposes to identify the source of this image.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
image → Image
The raw image pixels.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
The linear scale factor for drawing this image at its intended size.
finalinherited
sizeBytes → int
The size of raw image pixels in bytes.
no setterinherited

Methods

clone() → ImageInfo
Creates an ImageInfo with a cloned image.
override
dispose() → void
Disposes of this object.
inherited
isCloneOf(ImageInfo other) → bool
Whether this ImageInfo is a clone of the other.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited